@@ -18,6 +18,10 @@ import {
   activateRSPDisplayVersionExtension,
 } from "./displayversion"
 
+import {
+  activateRSPQueryExtension,
+} from "./query"
+
 import {
   activateRSPSavequitExtension,
 } from "./savequit"
@@ -33,6 +37,9 @@ function activateRSPExtension(app: JupyterFrontEnd, mainMenu: IMainMenu, docMana
   console.log('...activating savequit extension...');
   activateRSPSavequitExtension(app, mainMenu, docManager);
   console.log('...activated...')
+  console.log('...activating query extension...');
+  activateRSPQueryExtension(app, mainMenu, docManager);
+  console.log('...activated...')
   console.log('...loaded rsp-lab-extension.')
 }
 
